########################################################################################
#Author: Michaela Kerschbaumer
#Contact: michaela.kerschbaumer[@]uni-graz.at
#Script for genus Caleremaeus 
#Last update: 04.05.2023
#Reference: Kerschbaumer, Schäffer & Pfingstl, 2023
#Claw shape variation in oribatid mites of the genera Carabodes and Caleremaeus: Exploring the interplay of habitat, ecology, and phylogenetics. 
#PeerJ 
########################################################################################
############################################
#Step 1 :Load all packages that will be used
############################################

library(geomorph)
library(readr)
library(factoextra)
library(ggplot2)
library(gridExtra)
library(shapes)
library(ape)
library(ggtree)
##################
#Step 2: Read data
##################
setwd("")

Cal_specimens <- read.csv("..../CaleremaeusData.csv", sep=";", stringsAsFactors=TRUE)
Cal_populations <- read.csv("..../Meanshape_Caleremaeus.csv", sep=";", stringsAsFactors=TRUE)
clawlinks <- read.csv("....clawlinks.csv", row.names=1, sep=";", quote="'", stringsAsFactors=TRUE)


#########Define Coordinates#######################
Cal_specimens_coords <- as.matrix(Cal_specimens[,-(1:11)]) 
Cal_specimens_coords <-arrayspecs(Cal_specimens_coords, 31, 2)
Cal_populations_coords <- as.matrix(Cal_populations[,-(1:3)]) 
Cal_populations_coords <-arrayspecs(Cal_populations_coords, 31, 2)

######### Define factors###########################
species<-as.factor(Cal_specimens$Species)
habitat<-as.factor(Cal_specimens$Habitat)
specipop<- Cal_specimens$specipop
Cal_specimens_nr<-as.character(Cal_specimens[ ,1])
Cal_specimens_id<-as.character(Cal_specimens[ ,2])
######### Define colors ###########################

colors_species<-  c("#0073C2FF", "#EFC000FF", "#A73030FF")    

colors_pops<- c("#0073C2FF","#0073C2FF","#0073C2FF",  
                "#EFC000FF", "#EFC000FF", "#EFC000FF",  
                "#A73030FF","#A73030FF","#A73030FF")


######### Measurements on Claw ###########################
clawlength <- as.numeric(Cal_specimens$Diameter.Claw)
bodylength <- as.numeric(Cal_specimens$Body.length)
clbl<-as.numeric(Cal_specimens$CL.BL)

lmks <- data.frame(a = c(1,12), b = c(12,3), c = c(1,3), d = c(1,2),
                   row.names = c("start", "end"))

lineardists <- interlmkdist(Cal_specimens_coords, lmks)
a<-lineardists[,1]
b<-lineardists[,2]
c<-lineardists[,3]
d<-lineardists[,4]

rad2deg <- function(rad) {(rad * 180) / (pi)}
deg2rad <- function(deg) {(deg * pi) / (180)}

alphaklammer<- (a^ 2-b^ 2-c^ 2)/(-2*b*c)
bethaklammer<- (b^ 2-a^ 2-c^ 2)/(-2*a*c)
alpha<- acos(alphaklammer)
alpha<-rad2deg(alpha)
betha<- acos(bethaklammer)
betha<-rad2deg(betha)

gamma<- 180-alpha-betha

################Defining curves in landmark set, sliding semilandmarks #########

clawcurves <- read_delim("sliders_Claw31.csv", ";", escape_double = FALSE,
                         col_names = c("before","slide","after"), trim_ws = TRUE)
clawcurves <- as.matrix(clawcurves[,])  

############################Procrustes GPA #####################################
Cal_specimens.gpa<-gpagen(Cal_specimens_coords, curves = clawcurves, ProcD = FALSE,verbose=TRUE, print.progress = T)
plot(Cal_specimens.gpa)
clawshape <- Cal_specimens.gpa$coords #
clawshape <- two.d.array(Cal_specimens.gpa$coords)#
clawsize <- Cal_specimens.gpa$Csize


##################PCA###############################
pca<- gm.prcomp(Cal_specimens.gpa$coords)
PC1<-pca$x[,1] 
PC2<-pca$x[,2]
summary(pca)
plot(pca$x[, 1:2],col = species, pch=20)
text(pca$x[, 1:2],labels = Cal_specimens_id, pos = 1, cex = 0.7)


Cal_specimens.prcomp<-prcomp(clawshape)
pp1<-fviz_pca_ind(Cal_specimens.prcomp, geom.ind = "point",pointshape = 21,
                  pointsize = 2,
                  alpha=0.3,
                  xlab=("PC1"),
                  ylab=("PC2"),
                  fill.ind = species,
                  palette=colors_species,
                  col.ind = "black", 
                  addEllipses = FALSE,
                  label = "var",
                  col.var = "black",
                  repel = TRUE,
                  legend.title = "species") +
  ggtitle("PCA") +
  theme(plot.title = element_text(hjust = 0.5))+
  theme(legend.text = element_text(face="italic", size=8))

pp2<-fviz_eig(Cal_specimens.prcomp, addlabels = TRUE)

grid.arrange(pp1,pp2,ncol=2)
###############################################################################
Caleremaeus.gdf<- geomorph.data.frame(specipop=specipop,
                                      bl=bodylength,
                                      cl=clawlength,
                                      gamma=gamma,
                                      habitat=habitat,
                                      shape=clawshape)

################ Disparity ####################################################
Disparity<-morphol.disparity(shape ~ 1, groups= ~ specipop, data = Caleremaeus.gdf, iter=999,
                             print.progress = F)

pvpopulation<-Disparity$Procrustes.var*100


disparity.df<-data.frame(specipop=attr(Disparity$Procrustes.var,"names"),
                         pvpopulation=pvpopulation)

PV_rounded<- round(pvpopulation, digits = 3)


ggplot(disparity.df,aes(x=specipop, y=pvpopulation, fill=specipop))+
  geom_bar(stat="identity",alpha=0.6)+
  geom_text( aes(label=PV_rounded), vjust=1.6, color="black", size=3.5)+
  scale_fill_manual(values=colors_pops)  +
  theme(axis.text.x = element_text(size = 10, angle=90, hjust=1))+
  labs(title="Claw Disparity  in different populations", 
       x="species and population", y = "procrustes variance (x 10?)")

ggplot(disparity.df,aes(x=specipop, y=pvpopulation, fill=specipop))+
  geom_bar(stat="identity",alpha=0.6)+
  geom_text( aes(label=PV_rounded), vjust=1.6, color="black", size=3.5)+
  scale_fill_manual(values=colors_pops)  +
  theme(axis.text.x = element_text(size = 10, angle=90, hjust=1))+
  labs(title="Claw Disparity  in different populations", 
       x="species and population", y = "procrustes variance (x 10?)")

# Caleremaeus.df  Plot of measurements--------------------------------------------------------------------

Caleremaeus.df<-data.frame(PC1=PC1, PC2=PC2, 
                           habitat=habitat, 
                           species=species,
                           gamma=gamma, specipop=specipop,
                           bl=bodylength,
                           cl=clawlength)

ggplot(Caleremaeus.df, aes(x = bl,y = cl, col=species)) +
  labs(title = "bl and cl in different populations of Caleremaeus")+
  geom_point() +
  geom_smooth(method=lm)+
  scale_color_manual(values=colors_species)

c2<-ggplot(Caleremaeus.df, aes(x = species, y = gamma, fill=specipop))+
  labs(title = "gamma")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")

c3<-ggplot(Caleremaeus.df, aes(x = species, y = cl, fill=specipop))+
  labs(title = "clawlength")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")

c4<-ggplot(Caleremaeus.df, aes(x = species, y = clbl, fill=specipop))+
  labs(title = "cl/bL")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")

c5<-ggplot(Caleremaeus.df, aes(x = species, y = bl, fill=specipop,show.legend=FALSE))+
  labs(title = "bodylength")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")
c5

grid.arrange(grobs= list( c2, c3, c4, c5),
             ncol=2, nrow=2,
             top = ("measurements in claws"))
########### Meanshapes groups###################################################

caleremaeus <- mshape(Cal_specimens.gpa$coords)
plotshapes(caleremaeus,joinline = c(1,4,5,6,7,8,9,10,11,
                                    12,13,14,15,16,17,3,
                                    31,30,29,28,27,26,25,24,23,
                                    22,21,20,19,18,2))
par(mfrow=c(1,3)) 
clig <- mshape(Cal_specimens.gpa$coords[,,which(species == "clig")])
plotshapes(clig,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))


calp <- mshape(Cal_specimens.gpa$coords[,,which(species == "calp")])
plotshapes(calp,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))

cmen <- mshape(Cal_specimens.gpa$coords[,,which(species == "cmen")])
plotshapes(cmen ,joinline = c(1,4,5,6,7,8,9,10,11,
                              12,13,14,15,16,17,3,
                              31,30,29,28,27,26,25,24,23,
                              22,21,20,19,18,2))

par(mfrow=c(1,1)) 


###############################################################################
###############################################################################

######### Define factors###########################
specipop_PS<- as.factor(Cal_populations$specipop)
species_PS<- as.factor(Cal_populations$species)


######### Define colors ###########################


colors_pops<- c("#0073C2FF","#0073C2FF","#0073C2FF",  
                "#EFC000FF", "#EFC000FF", "#EFC000FF",  
                "#A73030FF","#A73030FF","#A73030FF")


######### GPA ###########################
Cal_populations.gpa<-gpagen(Cal_populations_coords, curves = clawcurves, ProcD = FALSE,verbose=TRUE, print.progress = T)

clawshape_PS <- Cal_populations.gpa$coords 
clawshape_PS <- two.d.array(Cal_populations.gpa$coords)
clawsize_PS <- Cal_populations.gpa$Csize


###########PCA######################################################
pca_PS<- gm.prcomp(clawshape_PS)

PC1_PS<-pca_PS$x[,1] 
PC2_PS<-pca_PS$x[,2]
summary(pca_PS) 

plot(pca_PS$x[, 1:2],col = species_PS, pch=20, cex=3)
text(pca_PS$x[, 1:2],labels = specipop_PS, pos = 1, cex = 0.7)  # specimen names

Cal_populations.prcomp<-prcomp(clawshape_PS)
fviz_pca_ind(Cal_populations.prcomp, geom.ind = "point",pointshape = 21,
             pointsize = 2,
             xlab=("PC1"),
             ylab=("PC2"),
             fill.ind = specipop_PS,
             palette=colors_pops,
             col.ind = "black", 
             addEllipses = F,
             label = rownames(Cal_populations),
             col.var = "black",
             repel = TRUE,
             legend.title = "species") +
  ggtitle("PCA of clawshape data- Caleremaeus populations") +
  theme(plot.title = element_text(hjust = 0))+
  theme(legend.text = element_text(face="italic", size=8))
############## Phylogenetic signal ###################################
tree<-read.tree(file="Caleremaeus_midpoint rooted")
plot(tree)

ggtree(tree) + ggtitle("Phylo Sylvia")+
  geom_tiplab(align=FALSE, linetype='dashed', linesize=.3)+
  geom_tippoint(size=5, alpha=.75)+ xlim(-2,3)


landmarkdata <- read.delim("C:/Users/kerschmi/OneDrive/R/R_caleremaeus/proc_caleremaeus_9pops.txt", row.names=1)

landmarkdata1 <- as.matrix(landmarkdata[,])  
phy<-read.tree(file="Caleremaeus_midpoint rooted")
plot(phy)
phy$tip.label

phy$tip.label<-c("C_mentobellus_CIA71",
                 "C_mentobellus_CIA72",
                 "C_mentobellus_CIA73",
                 "C_alpinus_CIA22",
                 "C_alpinus_CIA40",
                 "C_alpinus_CIA76",
                 "C_lignophilus_CIA58",
                 "C_lignophilus_CIA69",
                 "C_lignophilus_CIA74")

PS.shape <- physignal(A=landmarkdata1,phy,iter=9999)
summary(PS.shape)
plot(PS.shape)
plot(PS.shape$PACA,phylo=TRUE)

##################################################################################
########################################################### END
