########################################################################################
#Author: Michaela Kerschbaumer
#Contact: michaela.kerschbaumer[@]uni-graz.at
#Script for genus Carabodes
#Last update: 04.05.2023
#Reference: Kerschbaumer, Schäffer & Pfingstl, 2023
#MClaw shape variation in oribatid mites of the genera Carabodes and Carabodes: Exploring the interplay of habitat, ecology, and phylogenetics. 
#PeerJ 
########################################################################################
############################################
#Step 1 :Load all packages that will be used
############################################

library(geomorph)
library(readr)
library(factoextra)
library(ggplot2)
library(gridExtra)
library(shapes)
library(ape)
library(ggtree)
##################
#Step 2: Read data
##################
setwd("")

Car_specimens <- read.csv(".........../CarabodesData.csv", sep=";", stringsAsFactors=TRUE)
Car_populations <- read.csv("........./Meanshapes_Carabodes.csv", sep=";", stringsAsFactors=TRUE)
clawlinks <- read.csv("....../clawlinks.csv", row.names=1, sep=";", quote="'", stringsAsFactors=TRUE)


#########Define Coordinates#######################
Car_specimens_coords <- as.matrix(Car_specimens[,-(1:11)]) 
Car_specimens_coords <-arrayspecs(Car_specimens_coords, 31, 2)
Car_populations_coords <- as.matrix(Car_populations[,-(1:3)]) 
Car_populations_coords <-arrayspecs(Car_populations_coords, 31, 2)

######### Define factors###########################
species<-as.factor(Car_specimens$Species)
habitat<-as.factor(Car_specimens$Habitat)
specipop<- Car_specimens$specipop
Car_specimens_nr<-as.character(Car_specimens[ ,1])
Car_specimens_id<-as.character(Car_specimens[ ,2])
######### Define colors ###########################

colors_species<-  c("#0073C2FF", "#EFC000FF", "#868686FF", "#A73030FF", "#003C67FF","#6a994e","#7AA6DCFF" ,"#8F7700FF","black")    



colors_pops<- c("#0073C2FF","#0073C2FF","#0073C2FF","#0073C2FF",  
                "#EFC000FF",  
                "#868686FF", "#868686FF", "#868686FF", "#868686FF",
                "#A73030FF",
                "#003C67FF", "#003C67FF",
                "#6a994e",
                "#7AA6DCFF","#7AA6DCFF",
                "#8F7700FF","#8F7700FF","#8F7700FF",
                "black","black")   

######### Measurements on Claw ###########################
clawlength <- as.numeric(Car_specimens$Diameter.Claw)
bodylength <- as.numeric(Car_specimens$Body.length)
clbl<-as.numeric(Car_specimens$CL.BL)

lmks <- data.frame(a = c(1,12), b = c(12,3), c = c(1,3), d = c(1,2),
                   row.names = c("start", "end"))

lineardists <- interlmkdist(Car_specimens_coords, lmks)
a<-lineardists[,1]
b<-lineardists[,2]
c<-lineardists[,3]
d<-lineardists[,4]

rad2deg <- function(rad) {(rad * 180) / (pi)}
deg2rad <- function(deg) {(deg * pi) / (180)}

alphaklammer<- (a^ 2-b^ 2-c^ 2)/(-2*b*c)
bethaklammer<- (b^ 2-a^ 2-c^ 2)/(-2*a*c)
alpha<- acos(alphaklammer)
alpha<-rad2deg(alpha)
betha<- acos(bethaklammer)
betha<-rad2deg(betha)

gamma<- 180-alpha-betha

################Defining curves in landmark set, sliding semilandmarks #########

clawcurves <- read_delim("sliders_Claw31.csv", ";", escape_double = FALSE,
                         col_names = c("before","slide","after"), trim_ws = TRUE)
clawcurves <- as.matrix(clawcurves[,])  

############################Procrustes GPA #####################################
Car_specimens.gpa<-gpagen(Car_specimens_coords, curves = clawcurves, ProcD = FALSE,verbose=TRUE, print.progress = T)
plot(Car_specimens.gpa)
clawshape <- Car_specimens.gpa$coords #
clawshape <- two.d.array(Car_specimens.gpa$coords)#
clawsize <- Car_specimens.gpa$Csize


##################PCA###############################
pca<- gm.prcomp(Car_specimens.gpa$coords)
PC1<-pca$x[,1] 
PC2<-pca$x[,2]
summary(pca)
plot(pca$x[, 1:2],col = species, pch=20)
text(pca$x[, 1:2],labels = Car_specimens_id, pos = 1, cex = 0.7)


Car_specimens.prcomp<-prcomp(clawshape)
pp1<-fviz_pca_ind(Car_specimens.prcomp, geom.ind = "point",pointshape = 21,
                  pointsize = 2,
                  alpha=0.3,
                  xlab=("PC1"),
                  ylab=("PC2"),
                  fill.ind = species,
                  palette=colors_species,
                  col.ind = "black", 
                  addEllipses = FALSE,
                  label = "var",
                  col.var = "black",
                  repel = TRUE,
                  legend.title = "species") +
  ggtitle("PCA") +
  theme(plot.title = element_text(hjust = 0.5))+
  theme(legend.text = element_text(face="italic", size=8))

pp2<-fviz_eig(Car_specimens.prcomp, addlabels = TRUE)

grid.arrange(pp1,pp2,ncol=2)
###############################################################################
Carabodes.gdf<- geomorph.data.frame(specipop=specipop,
                                      bl=bodylength,
                                      cl=clawlength,
                                      gamma=gamma,
                                      habitat=habitat,
                                      shape=clawshape)

################ Disparity ####################################################
Disparity<-morphol.disparity(shape ~ 1, groups= ~ specipop, data = Carabodes.gdf, iter=999,
                             print.progress = F)

pvpopulation<-Disparity$Procrustes.var*100


disparity.df<-data.frame(specipop=attr(Disparity$Procrustes.var,"names"),
                         pvpopulation=pvpopulation)

PV_rounded<- round(pvpopulation, digits = 3)


ggplot(disparity.df,aes(x=specipop, y=pvpopulation, fill=specipop))+
  geom_bar(stat="identity",alpha=0.6)+
  geom_text( aes(label=PV_rounded), vjust=1.6, color="black", size=3.5)+
  scale_fill_manual(values=colors_pops)  +
  theme(axis.text.x = element_text(size = 10, angle=90, hjust=1))+
  labs(title="Claw Disparity  in different populations", 
       x="species and population", y = "procrustes variance (x 10?)")

ggplot(disparity.df,aes(x=specipop, y=pvpopulation, fill=specipop))+
  geom_bar(stat="identity",alpha=0.6)+
  geom_text( aes(label=PV_rounded), vjust=1.6, color="black", size=3.5)+
  scale_fill_manual(values=colors_pops)  +
  theme(axis.text.x = element_text(size = 10, angle=90, hjust=1))+
  labs(title="Claw Disparity  in different populations", 
       x="species and population", y = "procrustes variance (x 10?)")

# Carabodes.df  Plot of measurements--------------------------------------------------------------------

Carabodes.df<-data.frame(PC1=PC1, PC2=PC2, 
                           habitat=habitat, 
                           species=species,
                           gamma=gamma, specipop=specipop,
                           bl=bodylength,
                           cl=clawlength)

ggplot(Carabodes.df, aes(x = bl,y = cl, col=species)) +
  labs(title = "bl and cl in different populations of Carabodes")+
  geom_point() +
  geom_smooth(method=lm)+
  scale_color_manual(values=colors_species)

c2<-ggplot(Carabodes.df, aes(x = species, y = gamma, fill=specipop))+
  labs(title = "gamma")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")

c3<-ggplot(Carabodes.df, aes(x = species, y = cl, fill=specipop))+
  labs(title = "clawlength")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")

c4<-ggplot(Carabodes.df, aes(x = species, y = clbl, fill=specipop))+
  labs(title = "cl/bL")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")

c5<-ggplot(Carabodes.df, aes(x = species, y = bl, fill=specipop,show.legend=FALSE))+
  labs(title = "bodylength")+
  geom_boxplot()+
  theme_bw()+
  theme(axis.text.x = element_text(size=10, angle=90, hjust=1, face = "italic"))+
  scale_fill_manual(values=colors_pops)+ theme(legend.position = "none")
c5

grid.arrange(grobs= list( c2, c3, c4, c5),
             ncol=2, nrow=2,
             top = ("measurements in claws"))
########### Meanshapes groups###################################################

par(mfrow=c(3,3)) 

care <- mshape(Car_specimens.gpa$coords[,,which(species == "care")])
plotshapes(care,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))


ccor <- mshape(Car_specimens.gpa$coords[,,which(species == "ccor")])
plotshapes(ccor,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))

crug <- mshape(Car_specimens.gpa$coords[,,which(species == "crug")])
plotshapes(crug,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))


clab <- mshape(Car_specimens.gpa$coords[,,which(species == "clab")])
plotshapes(clab,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))
cmar <- mshape(Car_specimens.gpa$coords[,,which(species == "cmar")])
plotshapes(cmar,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))


corn <- mshape(Car_specimens.gpa$coords[,,which(species == "corn")])
plotshapes(corn,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))

cten <- mshape(Car_specimens.gpa$coords[,,which(species == "cten")])
plotshapes(cten,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))
cret <- mshape(Car_specimens.gpa$coords[,,which(species == "cret")])
plotshapes(cret,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))

oelo <- mshape(Car_specimens.gpa$coords[,,which(species == "oelo")])
plotshapes(oelo,joinline = c(1,4,5,6,7,8,9,10,11,
                             12,13,14,15,16,17,3,
                             31,30,29,28,27,26,25,24,23,
                             22,21,20,19,18,2))

par(mfrow=c(1,1)) 


###############################################################################
###############################################################################

######### Define factors###########################
specipop_PS<- as.factor(Car_populations$specipop)
species_PS<- as.factor(Car_populations$species)

######### GPA ###########################
Car_populations.gpa<-gpagen(Car_populations_coords, curves = clawcurves, ProcD = FALSE,verbose=TRUE, print.progress = T)

clawshape_PS <- Car_populations.gpa$coords 
clawshape_PS <- two.d.array(Car_populations.gpa$coords)
clawsize_PS <- Car_populations.gpa$Csize


###########PCA######################################################
pca_PS<- gm.prcomp(clawshape_PS)

PC1_PS<-pca_PS$x[,1] 
PC2_PS<-pca_PS$x[,2]
summary(pca_PS) 

plot(pca_PS$x[, 1:2],col = species_PS, pch=20, cex=3)
text(pca_PS$x[, 1:2],labels = specipop_PS, pos = 1, cex = 0.7)  # specimen names

Car_populations.prcomp<-prcomp(clawshape_PS)
fviz_pca_ind(Car_populations.prcomp, geom.ind = "point",pointshape = 21,
             pointsize = 2,
             xlab=("PC1"),
             ylab=("PC2"),
             fill.ind = specipop_PS,
             palette=colors_pops,
             col.ind = "black", 
             addEllipses = F,
             label = rownames(Car_populations),
             col.var = "black",
             repel = TRUE,
             legend.title = "species") +
  ggtitle("PCA of clawshape data- Carabodes populations") +
  theme(plot.title = element_text(hjust = 0))+
  theme(legend.text = element_text(face="italic", size=8))
############## Phylogenetic signal ###################################

ggtree(tree) + ggtitle("Phylo Sylvia")+
  geom_tiplab(align=FALSE, linetype='dashed', linesize=.3)+
  geom_tippoint(size=5, alpha=.75)+ xlim(-2,3)


landmarkdata <- read.delim("C:/Users/kerschmi/OneDrive/R/R_Carabodes/Proc_pops_carabodes.txt", row.names=1)

landmarkdata1 <- as.matrix(landmarkdata[,])  
phy<-read.tree(file="Carabodes_partition_midpoint rooted")
plot(phy)


phy$tip.label<- c("Carabodes_areolatus_CIA03", 
                  "Carabodes_areolatus_CIA55", 
                  "Carabodes_areolatus_CIA56", 
                  "Carabodes_areolatus_CIA74", 
                  "Carabodes_ornatus_CIA42", 
                  "Carabodes_ornatus_CIA74", 
                  "Carabodes_coriaceus_CIA09", 
                  "Carabodes_marginatus_CIA12", 
                  "Carabodes_labyrinthicus_CIA21",
                  "Carabodes_labyrinthicus_CIA09",
                  "Carabodes_labyrinthicus_CIA45",
                  "Carabodes_labyrinthicus_CIA47", 
                  "Carabodes_rugosior_CIA67", 
                  "Carabodes_rugosior_CIA77", 
                  "Carabodes_tenuis_CIA58",
                  "Carabodes_tenuis_CIA74", 
                  "Carabodes_tenuis_CIA59", 
                  "Carabodes_reticulatus_BF03")

PS.shape <- physignal(A=landmarkdata1,phy,iter=9999)
summary(PS.shape)
plot(PS.shape)
plot(PS.shape$PACA,phylo=TRUE)

##################################################################################
########################################################### END
